aboutsummaryrefslogtreecommitdiffstats
path: root/GPL/traffic_scripts/PacketVerifier.py
diff options
context:
space:
mode:
authorPeter Mikus <pmikus@cisco.com>2020-12-08 15:01:28 +0000
committerPeter Mikus <pmikus@cisco.com>2020-12-08 15:01:28 +0000
commita318ebefc569c5c1b1527c5de6dd3e3ac2f9c163 (patch)
tree492ab231caf5a4c82c93a86d661f5c5c17fbcfb1 /GPL/traffic_scripts/PacketVerifier.py
parenta9f54ca5080aeef17686f300a6807bf9b46b7c90 (diff)
Revert "vpp-device: GENEVE tunnel test, l3 mode"
This reverts commit a9f54ca5080aeef17686f300a6807bf9b46b7c90. Reason for revert: DO NOT MERGE BROKEN TESTS!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! https://logs.fd.io/production/vex-yul-rot-jenkins-1/csit-vpp-device-master-ubuntu1804-1n-skx/9918/archives/log.html.gz Change-Id: I2ce2970a43e5dd7487eeb54d1ccbb149e06cf8fa Signed-off-by: pmikus <pmikus@cisco.com>
Diffstat (limited to 'GPL/traffic_scripts/PacketVerifier.py')
-rw-r--r--GPL/traffic_scripts/PacketVerifier.py5
1 files changed, 2 insertions, 3 deletions
diff --git a/GPL/traffic_scripts/PacketVerifier.py b/GPL/traffic_scripts/PacketVerifier.py
index bb91b9361c..c915921625 100644
--- a/GPL/traffic_scripts/PacketVerifier.py
+++ b/GPL/traffic_scripts/PacketVerifier.py
@@ -331,10 +331,9 @@ def create_gratuitous_arp_request(src_mac, src_ip):
def auto_pad(packet):
"""Pads zeroes at the end of the packet if the total packet length is less
then 60 bytes in case of IPv4 or 78 bytes in case of IPv6.
"""
- # TODO: add document explaining deduction of FCS part
- min_len = 78 if packet.haslayer(IPv6) else 60
+ min_len = 78 if packet.haslayer(IPv6) else 64
pad_layer = Raw if packet.haslayer(Raw) \
else Padding if packet.haslayer(Padding) else None
if pad_layer:
@@ -331,10 +331,9 @@ def create_gratuitous_arp_request(src_mac, src_ip):
def auto_pad(packet):
"""Pads zeroes at the end of the packet if the total packet length is less
- then 60 bytes in case of IPv4 or 78 bytes in case of IPv6.
+ then 64 bytes in case of IPv4 or 78 bytes in case of IPv6.
"""